==> ejc-ai-impl-3.0.0-20250314.114159-47-sources.jar: com/ejianc/foundation/ai/bean/KnowledgeEmbeddingPointsEntity.java <==
package com.ejianc.foundation.ai.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 知识库切片知识点表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ai_knowledge_embedding_points")
public class KnowledgeEmbeddingPointsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="embedding_id")
    private Long embeddingId; // 切片ID
    @TableField(value="uuid")
    private String uuid; // 系统生成id
    @TableField(value="vector")
    private String vector; // 向量
    @TableField(value="content")
    private String content; // 知识内容
    @TableField(value="init_content")
    private String initContent; // 自动生成的初始化的知识内容
    @TableField(value="type")
    private Integer type; //类型，1自动生成，2自定义新增

    public Long getEmbeddingId() {
        return embeddingId;
    }

    public void setEmbeddingId(Long embeddingId) {
        this.embeddingId = embeddingId;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getVector() {
        return vector;
    }

    public void setVector(String vector) {
        this.vector = vector;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getInitContent() {
        return initContent;
    }

    public void setInitContent(String initContent) {
        this.initContent = initContent;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
}

==> ejc-ai-impl-3.0.0-20250407.084013-67-sources.jar: com/ejianc/foundation/ai/bean/KnowledgeEmbeddingPointsEntity.java <==
package com.ejianc.foundation.ai.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 知识库切片知识点表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ai_knowledge_embedding_points")
public class KnowledgeEmbeddingPointsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="embedding_id")
    private Long embeddingId; // 切片ID
    @TableField(value="uuid")
    private String uuid; // 系统生成id
    @TableField(value="vector")
    private String vector; // 向量
    @TableField(value="content")
    private String content; // 知识内容
    @TableField(value="init_content")
    private String initContent; // 自动生成的初始化的知识内容
    @TableField(value="type")
    private Integer type; //类型，1自动生成，2自定义新增
    @TableField(value="sequence")
    private Integer sequence; // 排序号

    public Long getEmbeddingId() {
        return embeddingId;
    }

    public void setEmbeddingId(Long embeddingId) {
        this.embeddingId = embeddingId;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getVector() {
        return vector;
    }

    public void setVector(String vector) {
        this.vector = vector;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getInitContent() {
        return initContent;
    }

    public void setInitContent(String initContent) {
        this.initContent = initContent;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
}
